/*------------------------------------*
  $SIDEBAR
*------------------------------------*/
#sidebar {
  font-size: 13px;
}

.sidebar-box {
  margin-bottom: 40px;
}

.sidebar-box ul {
  margin: 0;
  padding: 0;
  list-style: none;
}

.widget-title {
  display: block;
  line-height: 1;
  font-size: 13px;
  font-weight: 400;
  color: #333;
  border-width: 0 0 0 3px;
  border-style: solid;
  border-color: #13aff0;
  letter-spacing: 1px;
  padding-left: 15px;
  margin: 0 0 20px;
  text-transform: uppercase;
}

/**
 * Widgets > Borders
 */
.oceanwp-widget-recent-posts-li,
.widget_categories li,
.widget_recent_entries li,
.widget_archive li,
.widget_recent_comments li,
.widget_layered_nav li,
.widget-recent-posts-icons li,
.site-footer .widget_nav_menu li {
  padding: 6px 0;
  border-bottom: 1px solid #e9e9e9;
}

.oceanwp-widget-recent-posts-li:first-child,
.widget_categories li:first-child,
.widget_recent_entries li:first-child,
.widget_archive li:first-child,
.widget_recent_comments li:first-child,
.widget_layered_nav li:first-child,
.widget-recent-posts-icons li:first-child,
.site-footer .widget_nav_menu li:first-child {
  border-top: 1px solid #e9e9e9;
}

/*------------------------------------*
  Phone Portrait and Landscape
*------------------------------------*/
@media only screen and (max-width: 767px) {
  /* sidebar  */
  #main .widget_nav_menu li a:before {
    display: none;
  }
}